pub struct CloseConfirmationUI { /* private fields */ }Expand description
State for the close confirmation dialog
Implementations
Sourceimpl CloseConfirmationUI
impl CloseConfirmationUI
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Check if the dialog is currently visible
Sourcepub fn show_for_tab(
&mut self,
tab_id: TabId,
tab_title: &str,
command_name: &str,
)
pub fn show_for_tab( &mut self, tab_id: TabId, tab_title: &str, command_name: &str, )
Show the confirmation dialog for a tab with a running command
Sourcepub fn show_for_pane(
&mut self,
tab_id: TabId,
pane_id: PaneId,
tab_title: &str,
command_name: &str,
)
pub fn show_for_pane( &mut self, tab_id: TabId, pane_id: PaneId, tab_title: &str, command_name: &str, )
Show the confirmation dialog for a pane with a running command
Sourcepub fn show(&mut self, ctx: &Context) -> CloseConfirmAction
pub fn show(&mut self, ctx: &Context) -> CloseConfirmAction
Render the dialog and return any action