pub enum TriggerSplitDirection {
Horizontal,
Vertical,
}Expand description
Split orientation for a new pane created by a trigger action.
Horizontalcreates a new pane below the existing one (stacked vertically).Verticalcreates a new pane to the right (side by side).
Variants
Horizontal
New pane below (panes stacked vertically).
Vertical
New pane to the right (side by side).