pub enum BackgroundImageMode {
Fit,
Fill,
Stretch,
Tile,
Center,
}Expand description
Background image display mode
Variants
Fit
Scale to fit window while maintaining aspect ratio (may have letterboxing)
Fill
Scale to fill window while maintaining aspect ratio (may crop edges)
Stretch
Stretch to fill window exactly (ignores aspect ratio)
Tile
Repeat image in a tiled pattern at original size
Center
Center image at original size (no scaling)