pub fn default_widgets() -> Vec<StatusBarWidgetConfig>Expand description
Default widget configuration set.
Returns a sensible starting set of widgets covering common use-cases. System monitor widgets (CPU, memory, network) are disabled by default to avoid unnecessary resource usage.