pub enum ConditionCheck {
ExitCode {
value: i32,
},
OutputContains {
pattern: String,
case_sensitive: bool,
},
EnvVar {
name: String,
value: Option<String>,
},
DirMatches {
pattern: String,
},
GitBranch {
pattern: String,
},
}Expand description
Condition to check for a Condition action.
Variants
ExitCode
Check the exit code of the last captured ShellCommand.
OutputContains
Check whether the last captured output contains a pattern.
EnvVar
Check an environment variable (None value = existence check only).
DirMatches
Glob match on the current terminal CWD.
GitBranch
Glob match on the current git branch.