InputConfig

Struct InputConfig 

pub struct InputConfig {
    pub left_option_key_mode: OptionKeyMode,
    pub right_option_key_mode: OptionKeyMode,
    pub modifier_remapping: ModifierRemapping,
    pub use_physical_keys: bool,
}
Option/Alt key behaviour, modifier remapping and physical key positions.

Fields

left_option_key_mode: OptionKeyMode

Left Option key (macOS) / Left Alt key (Linux/Windows) behavior

  • normal: Sends special characters (default macOS behavior)
  • meta: Sets the high bit (8th bit) on the character
  • esc: Sends Escape prefix before the character (most compatible for emacs/vim)
right_option_key_mode: OptionKeyMode

Right Option key (macOS) / Right Alt key (Linux/Windows) behavior Can be configured independently from left Option key

  • normal: Sends special characters (default macOS behavior)
  • meta: Sets the high bit (8th bit) on the character
  • esc: Sends Escape prefix before the character (most compatible for emacs/vim)
modifier_remapping: ModifierRemapping

Modifier key remapping configuration Allows remapping modifier keys to different functions (e.g., swap Ctrl and Caps Lock)

use_physical_keys: bool

Use physical key positions for keybindings instead of logical characters When enabled, keybindings work based on key position (scan code) rather than the character produced, making shortcuts consistent across keyboard layouts. For example, Ctrl+Z will always be the bottom-left key regardless of QWERTY/AZERTY/Dvorak.