pub struct ResolvedCursorShaderConfig {
pub base: ResolvedShaderConfig,
pub hides_cursor: bool,
pub disable_in_alt_screen: bool,
pub glow_radius: f32,
pub glow_intensity: f32,
pub trail_duration: f32,
pub cursor_color: [u8; 3],
}Expand description
Fully resolved cursor shader configuration with all values filled in.
Fields
base: ResolvedShaderConfigBase resolved shader config
hides_cursor: boolHide the default cursor when this shader is enabled
disable_in_alt_screen: boolDisable cursor shader while in alt screen (vim, less, htop)
glow_radius: f32Cursor glow radius in pixels
glow_intensity: f32Cursor glow intensity (0.0-1.0)
trail_duration: f32Duration of cursor trail effect in seconds
cursor_color: [u8; 3]Cursor color for shader effects [R, G, B] (0-255)
Implementations
Sourceimpl ResolvedCursorShaderConfig
impl ResolvedCursorShaderConfig
Sourcepub fn for_shader(
shader_name: &str,
metadata: Option<&CursorShaderMetadata>,
config: &Config,
) -> ResolvedCursorShaderConfig
pub fn for_shader( shader_name: &str, metadata: Option<&CursorShaderMetadata>, config: &Config, ) -> ResolvedCursorShaderConfig
Resolve a cursor shader config for a specific shader.
Arguments
shader_name- Name of the cursor shader filemetadata- Optional cursor shader metadataconfig- Global config