pub struct TabConfig {Show 17 fields
pub tab_style: TabStyle,
pub light_tab_style: TabStyle,
pub dark_tab_style: TabStyle,
pub tab_bar_mode: TabBarMode,
pub tab_title_mode: TabTitleMode,
pub remote_tab_title_format: RemoteTabTitleFormat,
pub remote_tab_title_osc_priority: bool,
pub tab_bar_height: f32,
pub tab_bar_position: TabBarPosition,
pub tab_bar_width: f32,
pub tab_show_close_button: bool,
pub tab_show_index: bool,
pub tab_inherit_cwd: bool,
pub max_tabs: usize,
pub show_profile_drawer_button: bool,
pub new_tab_shortcut_shows_profiles: bool,
pub new_tab_position: NewTabPosition,
}Expand description
Tab style presets, tab bar placement and new-tab behaviour.
Fields
tab_style: TabStyleTab visual style preset (dark, light, compact, minimal, high_contrast, automatic) Applies cosmetic color/size/spacing presets to the tab bar
light_tab_style: TabStyleTab style to use when system is in light mode (used when tab_style is Automatic)
dark_tab_style: TabStyleTab style to use when system is in dark mode (used when tab_style is Automatic)
tab_bar_mode: TabBarModeTab bar visibility mode (always, when_multiple, never)
tab_title_mode: TabTitleModeControls how tab titles are automatically updated (auto or osc_only)
remote_tab_title_format: RemoteTabTitleFormatFormat for tab title when shell integration detects a remote host
remote_tab_title_osc_priority: boolWhen true, explicit OSC title sequences override remote_tab_title_format
tab_bar_height: f32Tab bar height in pixels
tab_bar_position: TabBarPositionTab bar position (top, bottom, left)
tab_bar_width: f32Tab bar width in pixels (used when tab_bar_position is Left)
Show close button on tabs
tab_show_index: boolShow tab index numbers (for Cmd+1-9)
tab_inherit_cwd: boolNew tab inherits working directory from active tab
max_tabs: usizeMaximum tabs per window (0 = unlimited)
Show the profile drawer toggle button on the right edge of the terminal When disabled, the profile drawer can still be opened via keyboard shortcut
new_tab_shortcut_shows_profiles: boolWhen true, the new-tab keyboard shortcut (Cmd+T / Ctrl+Shift+T) shows the profile selection dropdown instead of immediately opening a default tab
new_tab_position: NewTabPositionWhere to insert new tabs in the tab bar.
end appends to the end (default); after_active inserts right of the active tab.