pub struct ThemeColorsConfig {
pub theme: String,
pub auto_dark_mode: bool,
pub light_theme: String,
pub dark_theme: String,
}Expand description
Terminal colour theme, plus the light/dark pair used by auto dark mode.
Fields
theme: StringColor theme name to use for terminal colors
auto_dark_mode: boolAutomatically switch theme based on system light/dark mode
light_theme: StringTheme to use when system is in light mode (used when auto_dark_mode is true)
dark_theme: StringTheme to use when system is in dark mode (used when auto_dark_mode is true)