CopyModeState

Struct CopyModeState 

pub struct CopyModeState {
Show 14 fields pub active: bool, pub cursor_col: usize, pub cursor_absolute_line: usize, pub visual_mode: VisualMode, pub selection_anchor: Option<(usize, usize)>, pub count: Option<usize>, pub pending_operator: Option<PendingOperator>, pub marks: HashMap<char, Mark>, pub cols: usize, pub rows: usize, pub scrollback_len: usize, pub search_query: String, pub search_direction: SearchDirection, pub is_searching: bool, /* private fields */
}
Copy mode state machine.

Uses absolute line indexing:

  • Line 0 = oldest scrollback line
  • Line scrollback_len - 1 = newest scrollback line
  • Line scrollback_len = top of visible screen (at scroll_offset=0)
  • Line scrollback_len + rows - 1 = bottom of visible screen

Fields

active: bool

Whether copy mode is active

cursor_col: usize

Cursor column position

cursor_absolute_line: usize

Cursor absolute line position

visual_mode: VisualMode

Current visual selection mode

selection_anchor: Option<(usize, usize)>

Selection anchor point (absolute_line, col) - set when entering visual mode

count: Option<usize>

Count prefix for motions (e.g., 5j moves down 5 lines)

pending_operator: Option<PendingOperator>

Pending operator waiting for a motion

marks: HashMap<char, Mark>

Named marks (a-z)

cols: usize

Terminal columns

rows: usize

Terminal rows

scrollback_len: usize

Scrollback buffer length

search_query: String

Current search query

search_direction: SearchDirection

Search direction

is_searching: bool

Whether search input mode is active

Implementations

Source

impl CopyModeState

pub fn new() -> Self

Create a new inactive copy mode state

pub fn enter( &mut self, cursor_col: usize, cursor_row: usize, cols: usize, rows: usize, scrollback_len: usize, )

Enter copy mode at the given cursor position

pub fn exit(&mut self)

Exit copy mode, clearing all state

pub fn push_count_digit(&mut self, digit: u8)

Push a digit to the count prefix

pub fn effective_count(&mut self) -> usize

Get the effective count (defaults to 1 if no count set)

pub fn move_left(&mut self)

Move cursor left by count

pub fn move_right(&mut self)

Move cursor right by count

pub fn move_up(&mut self)

Move cursor up by count

pub fn move_down(&mut self)

Move cursor down by count

pub fn move_to_line_start(&mut self)

Move cursor to start of line

pub fn move_to_line_end(&mut self)

Move cursor to end of line

pub fn move_to_first_non_blank(&mut self, line_text: &str)

Move cursor to first non-blank character on the line

pub fn move_word_forward(&mut self, line_text: &str, word_chars: &str)

Move forward to start of next word

pub fn move_word_backward(&mut self, line_text: &str, word_chars: &str)

Move backward to start of previous word

pub fn move_word_end(&mut self, line_text: &str, word_chars: &str)

Move forward to end of current/next word

pub fn move_big_word_forward(&mut self, line_text: &str)

Move forward to start of next WORD (whitespace-delimited)

pub fn move_big_word_backward(&mut self, line_text: &str)

Move backward to start of previous WORD (whitespace-delimited)

pub fn move_big_word_end(&mut self, line_text: &str)

Move forward to end of current/next WORD (whitespace-delimited)

pub fn half_page_up(&mut self)

Move half page up

pub fn half_page_down(&mut self)

Move half page down

pub fn page_up(&mut self)

Move full page up

pub fn page_down(&mut self)

Move full page down

pub fn goto_top(&mut self)

Go to top of buffer (line 0)

pub fn goto_bottom(&mut self)

Go to bottom of buffer (last line)

pub fn goto_line(&mut self, line: usize)

Go to specific absolute line (for count+G)

pub fn toggle_visual_char(&mut self)

Toggle character-wise visual mode

pub fn toggle_visual_line(&mut self)

Toggle line-wise visual mode

pub fn toggle_visual_block(&mut self)

Toggle block/rectangular visual mode

pub fn compute_selection(&self, scroll_offset: usize) -> Option<Selection>

Compute a Selection from the current visual mode state.

The selection coordinates are in screen-relative terms (row = line - viewport_top) for rendering. scroll_offset is the current viewport scroll position.

pub fn set_mark(&mut self, name: char)

Set a named mark at the current cursor position

pub fn goto_mark(&mut self, name: char) -> bool

Jump to a named mark, returning true if the mark exists

Start search input mode

pub fn search_input(&mut self, ch: char)

Add a character to the search query

pub fn search_backspace(&mut self)

Remove the last character from the search query

Cancel search mode without executing

pub fn screen_cursor_pos(&self, scroll_offset: usize) -> Option<(usize, usize)>

Get the cursor position in screen coordinates, if visible.

Returns (col, row) where row is relative to the viewport top. Returns None if the cursor is outside the visible viewport.

pub fn required_scroll_offset(&self, current_offset: usize) -> Option<usize>

Calculate the scroll offset needed to make the cursor visible.

Returns Some(new_offset) if scrolling is needed, None if cursor is already visible.

pub fn update_dimensions( &mut self, cols: usize, rows: usize, scrollback_len: usize, )

Update the scrollback length (call when terminal state changes)

pub fn status_text(&self) -> String

Get a status line description of the current mode