InputHandler

Struct InputHandler 

pub struct InputHandler {
    pub modifiers: Modifiers,
    pub left_option_key_mode: OptionKeyMode,
    pub right_option_key_mode: OptionKeyMode,
    /* private fields */
}
Input handler for converting winit events to terminal input

Fields

modifiers: Modifiersleft_option_key_mode: OptionKeyMode

Option key mode for left Option/Alt key

right_option_key_mode: OptionKeyMode

Option key mode for right Option/Alt key

Implementations

Source

impl InputHandler

pub fn new() -> InputHandler

Create a new input handler

pub fn update_modifiers(&mut self, modifiers: Modifiers)

Update the current modifier state

pub fn update_option_key_modes( &mut self, left: OptionKeyMode, right: OptionKeyMode, )

Update Option/Alt key modes from config

pub fn track_alt_key(&mut self, event: &KeyEvent)

Track Alt key press/release to know which Alt is active

pub fn handle_key_event(&mut self, event: KeyEvent) -> Option<Vec<u8>>

Convert a keyboard event to terminal input bytes

If modify_other_keys_mode is > 0, keys with modifiers will be reported using the XTerm modifyOtherKeys format: CSI 27 ; modifier ; keycode ~

pub fn handle_key_event_with_mode( &mut self, event: KeyEvent, modify_other_keys_mode: u8, application_cursor: bool, ) -> Option<Vec<u8>>

Convert a keyboard event to terminal input bytes with modifyOtherKeys support

modify_other_keys_mode:

  • 0: Disabled (normal key handling)
  • 1: Report modifiers for special keys only
  • 2: Report modifiers for all keys

application_cursor: When true (DECCKM mode enabled), arrow keys send SS3 sequences (ESC O A) instead of CSI sequences (ESC [ A).

pub fn paste_from_clipboard(&mut self) -> Option<String>

Paste text from clipboard (returns raw text, caller handles terminal conversion)

pub fn clipboard_has_image(&mut self) -> bool

Check if clipboard contains an image (used when text paste returns None to determine if we should forward the paste event to the terminal for image-aware applications like Claude Code)

pub fn copy_to_clipboard(&mut self, text: &str) -> Result<(), String>

Copy text to clipboard

pub fn copy_to_primary_selection(&mut self, text: &str) -> Result<(), String>

Copy text to primary selection (Linux X11 only)

pub fn paste_from_primary_selection(&mut self) -> Option<String>

Paste text from primary selection (Linux X11 only, returns raw text)