request_toggle

Function request_toggle 

pub fn request_toggle()
Ask the in-app menu to open (or close, if already open).

The request is applied by the next egui pass that draws the menu, so this is safe to call from the input handler — for example from a toggle_menu keybinding action.