Remote shell integration install confirmation dialog.
Shows a confirmation dialog when the user selects “Install Shell Integration on Remote Host” from the Shell menu. Displays the exact curl command that will be sent to the active terminal and lets the user confirm or cancel.
Structs
- Remote
Shell InstallUI - State for the remote shell integration install dialog
Enums
- Remote
Shell Install Action - Action returned by the remote shell install dialog