Module scrollback_metadata

Module scrollback_metadata 

Scrollback metadata for shell integration markers.

This module re-exports types from the par-term-terminal crate for backward compatibility.

Structs

CommandSnapshot
Lightweight snapshot of a completed command taken from the core library.
LineMetadata
Metadata for displaying timing/command info for a specific line.
ScrollbackMark
Public-facing metadata for a mark anchored to a scrollback line.
ScrollbackMetadata