Module capture

Module capture 

Capture current session state from live windows

Functions

capture_pane_node
Recursively capture a pane tree node into a session-serializable form
capture_session
Capture the current session state from all open windows