pub fn capture_session(windows: &HashMap<WindowId, WindowState>) -> SessionStateExpand description
Capture the current session state from all open windows
pub fn capture_session(windows: &HashMap<WindowId, WindowState>) -> SessionStateCapture the current session state from all open windows