pub fn load_session() -> Result<Option<SessionState>>Expand description
Load session state from the default location
Returns None if the file doesn’t exist or is empty.
Returns an error if the file exists but is corrupt.
pub fn load_session() -> Result<Option<SessionState>>Load session state from the default location
Returns None if the file doesn’t exist or is empty.
Returns an error if the file exists but is corrupt.