pub fn quote_path(path: &Path, style: DroppedFileQuoteStyle) -> StringExpand description
Quote a file path according to the specified style.
pub fn quote_path(path: &Path, style: DroppedFileQuoteStyle) -> StringQuote a file path according to the specified style.