pub struct SmartSelectionCache { /* private fields */ }Expand description
Cache for compiled smart selection matchers to avoid recompilation
Implementations
Sourceimpl SmartSelectionCache
impl SmartSelectionCache
pub fn new() -> Self
Sourcepub fn get_matcher(
&mut self,
rules: &[SmartSelectionRule],
) -> &SmartSelectionMatcher
pub fn get_matcher( &mut self, rules: &[SmartSelectionRule], ) -> &SmartSelectionMatcher
Get or create a matcher for the given rules