pub enum TabBarAction {
Show 16 variants
None,
SwitchTo(TabId),
Close(TabId),
NewTab,
NewTabWithProfile(ProfileId),
Reorder(TabId, usize),
SetColor(TabId, [u8; 3]),
ClearColor(TabId),
Duplicate(TabId),
RenameTab(TabId, String),
SetTabIcon(TabId, Option<String>),
ToggleAssistantPanel,
MoveTabToNewWindow(TabId),
MoveTabToExistingWindow(TabId, WindowId),
PromotePaneToTab(TabId),
DemoteTabToPane(TabId),
}Expand description
Actions that can be triggered from the tab bar
Variants
None
No action
SwitchTo(TabId)
Switch to a specific tab
Close(TabId)
Close a specific tab
NewTab
Create a new tab
NewTabWithProfile(ProfileId)
Create a new tab from a specific profile
Reorder(TabId, usize)
Reorder a tab to a new position
SetColor(TabId, [u8; 3])
Set custom color for a tab
ClearColor(TabId)
Clear custom color for a tab (revert to default)
Duplicate(TabId)
Duplicate a specific tab
RenameTab(TabId, String)
Rename a specific tab
SetTabIcon(TabId, Option<String>)
Set custom icon for a tab (None = clear)
ToggleAssistantPanel
Toggle the AI assistant panel
MoveTabToNewWindow(TabId)
Move a tab to a brand-new par-term window.
MoveTabToExistingWindow(TabId, WindowId)
Move a tab into an existing par-term window.
PromotePaneToTab(TabId)
Promote the focused pane of this tab to a new tab
DemoteTabToPane(TabId)
Start demote pick mode for this tab