pub struct CommandHistoryUI {
pub visible: bool,
/* private fields */
}Expand description
Command history UI manager using egui
Fields
visible: boolWhether the command history window is currently visible
Implementations
Sourceimpl CommandHistoryUI
impl CommandHistoryUI
Sourcepub fn update_entries(&mut self, entries: &VecDeque<CommandHistoryEntry>)
pub fn update_entries(&mut self, entries: &VecDeque<CommandHistoryEntry>)
Update cached entries from persistent command history
Sourcepub fn select_previous(&mut self)
pub fn select_previous(&mut self)
Navigate selection up
Sourcepub fn selected_command(&self) -> Option<String>
pub fn selected_command(&self) -> Option<String>
Get the command text of the currently selected entry (if any). Re-runs fuzzy matching to resolve the filtered index.
Sourcepub fn select_next(&mut self, filtered_count: usize)
pub fn select_next(&mut self, filtered_count: usize)
Navigate selection down
Sourcepub fn show(&mut self, ctx: &Context) -> CommandHistoryAction
pub fn show(&mut self, ctx: &Context) -> CommandHistoryAction
Show the command history window and return any action to take