SemanticHistoryConfig

Struct SemanticHistoryConfig 

pub struct SemanticHistoryConfig {
    pub semantic_history_enabled: bool,
    pub semantic_history_editor_mode: SemanticHistoryEditorMode,
    pub semantic_history_editor: String,
    pub link_highlight_color: [u8; 3],
    pub link_highlight_color_enabled: bool,
    pub link_highlight_underline: bool,
    pub link_underline_style: LinkUnderlineStyle,
    pub link_handler_command: String,
    pub allow_file_scheme_urls: bool,
}
File-path/URL detection, the editor that opens them, and link highlighting.

Fields

semantic_history_enabled: bool

Enable semantic history (file path detection and opening) When enabled, Cmd/Ctrl+Click on detected file paths opens them in the editor.

semantic_history_editor_mode: SemanticHistoryEditorMode

Editor selection mode for semantic history

  • custom - Use the editor command specified in semantic_history_editor
  • environment_variable - Use $EDITOR or $VISUAL environment variable (default)
  • system_default - Use system default application for each file type
semantic_history_editor: String

Editor command for semantic history (when mode is custom).

Placeholders: {file} = file path, {line} = line number (if available)

Examples:

  • code -g {file}:{line} (VS Code with line number)
  • subl {file}:{line} (Sublime Text)
  • vim +{line} {file} (Vim)
  • emacs +{line} {file} (Emacs)
link_highlight_color: [u8; 3]

Color for highlighted links (URLs and file paths) [R, G, B] (0-255)

link_highlight_color_enabled: bool

Apply color to highlighted links (URLs and file paths)

link_highlight_underline: bool

Underline highlighted links (URLs and file paths)

link_underline_style: LinkUnderlineStyle

Style for link highlight underlines (solid or stipple)

link_handler_command: String

Custom command to open URLs. When set, used instead of system default browser.

Use {url} as placeholder for the URL.

Examples:

  • firefox {url} (open in Firefox)
  • open -a Safari {url} (macOS: open in Safari)
  • chromium-browser {url} (Linux: open in Chromium)

When empty or unset, uses the system default browser.

allow_file_scheme_urls: bool

Allow Cmd+Click (macOS) / Ctrl+Click to open file:// OSC 8 hyperlinks and file URLs via the OS default handler (browser for .html, Finder for directories, etc.).

Disabled by default for security (SEC-009): a remote program can emit an OSC 8 hyperlink with a file:// scheme to make the OS handler open an arbitrary local path. Enable only if you trust your terminal sessions.