GPU utility re-exports from par-term-render crate.
This module re-exports types from the par-term-render crate for backward compatibility.
Functions
- create_
linear_ sampler - Create a linear sampler with ClampToEdge address mode.
- create_
render_ texture - Create an RGBA texture with render target usage.
- create_
repeat_ sampler - Create a linear sampler with Repeat address mode.
- create_
rgba_ texture - Create an RGBA texture with the specified dimensions.
- create_
sampler_ with_ filter - Create a sampler with the specified filter mode and ClampToEdge address mode.
- write_
rgba_ texture - Write RGBA pixel data to a texture.
- write_
rgba_ texture_ region - Write RGBA pixel data to a specific region of a texture.