pub struct MenuManager { /* private fields */ }Expand description
Manages the native menu system
Implementations
Sourceimpl MenuManager
impl MenuManager
Sourcepub fn init_for_window(&self, window: &Arc<Window>) -> Result<()>
pub fn init_for_window(&self, window: &Arc<Window>) -> Result<()>
Initialize the menu for a window
On macOS, this initializes the global application menu (only needs to be called once). On Windows/Linux, this attaches a menu bar to the specific window.
Sourcepub fn poll_events(&self) -> impl Iterator<Item = MenuAction> + '_
pub fn poll_events(&self) -> impl Iterator<Item = MenuAction> + '_
Poll for menu events and return any triggered actions
Sourcepub fn update_profiles(&mut self, profiles: &[&Profile])
pub fn update_profiles(&mut self, profiles: &[&Profile])
Update the profiles submenu with the current list of profiles
This should be called whenever profiles are loaded or modified.
Sourcepub fn update_profiles_from_manager(&mut self, manager: &ProfileManager)
pub fn update_profiles_from_manager(&mut self, manager: &ProfileManager)
Update profiles from a ProfileManager (convenience method)