Paste transformation utilities.
Provides text transformations for the “Paste Special” feature, allowing users to transform clipboard content before pasting (shell escaping, case conversion, encoding, whitespace normalization, etc.).
Sub-modules
case— case conversion (title, camel, pascal, snake, screaming snake, kebab)encoding— Base64, URL, Hex, and JSON escape/unescapesanitize— clipboard content sanitization (strip dangerous control chars)shell— shell quoting and backslash escapingwhitespace— whitespace and newline normalization
Enums
- Paste
Transform - Available paste transformations.
Functions
- paste_
contains_ control_ chars - Check whether a paste string contains dangerous control characters that would
be stripped by
sanitize_paste_content. - sanitize_
paste_ content - Sanitize clipboard paste content by stripping dangerous control characters.
- transform
- Apply a transformation to the input text.