pub fn primary_modifier_with_shift(mods: &ModifiersState) -> boolExpand description
Returns true when the platform’s primary modifier key and Shift
are held, and no other modifiers are held, i.e.:
- macOS:
Cmd+Shift;AltandCtrlnot pressed - Windows/Linux:
Ctrl+Shift;AltandSupernot pressed
Use this for shortcuts that require Shift to avoid conflicts
(Cmd+Shift+] on macOS / Ctrl+Shift+] elsewhere). Like
primary_modifier, this excludes the cross modifier and Alt so that
combos such as Ctrl+Cmd+Shift+] do not shadow separate keybindings.