Profile management for terminal session configurations
This module provides an iTerm2-style profile system that allows users to save terminal session configurations including:
- Working directory for the session
- Custom command with arguments
- Custom tab name
Profiles are stored in ~/.config/par-term/profiles.yaml.
Re-exports
pub use dynamic::CacheMeta;pub use dynamic::DynamicProfileManager;pub use dynamic::DynamicProfileUpdate;pub use dynamic::FetchResult;pub use dynamic::SourceStatus;pub use dynamic::cache_dir;pub use dynamic::fetch_profiles;pub use dynamic::merge_dynamic_profiles;pub use dynamic::read_cache;pub use dynamic::url_to_cache_filename;pub use dynamic::write_cache;
Modules
- dynamic
- Dynamic profile source configuration, fetch, cache, merge, and manager.
- storage
- Storage utilities for profile persistence
Structs
- Dynamic
Profile Source - A remote profile source configuration stored in the main config file
- Profile
- A terminal session profile containing configuration for how to start a session
- Profile
Manager - Manages a collection of profiles
Enums
- Conflict
Resolution - How to resolve conflicts when a remote profile has the same ID as a local one
- Profile
Source - Tracks where a profile came from (runtime-only, not persisted)
Type Aliases
- Profile
Id - Unique identifier for a profile