Scrollback metadata for shell integration markers.
This module re-exports types from the par-term-terminal crate for backward compatibility.
Structs
- Command
Snapshot - Lightweight snapshot of a completed command taken from the core library.
- Line
Metadata - Metadata for displaying timing/command info for a specific line.
- Scrollback
Mark - Public-facing metadata for a mark anchored to a scrollback line.
- Scrollback
Metadata