pub fn detected_shells() -> &'static [ShellInfo]Expand description
Get the list of available shells on the current system.
Results are cached after the first call. The list is sorted with common shells first and always includes shells that actually exist on disk.