pub struct Tab {
pub id: TabId,
pub terminal: Arc<Mutex<TerminalManager>>,
pub title: String,
pub has_activity: bool,
pub scroll_state: ScrollState,
pub mouse: MouseState,
pub bell: BellState,
pub cache: RenderCache,
pub refresh_task: Option<JoinHandle<()>>,
pub working_directory: Option<String>,
}Expand description
A single terminal tab with its own state
Fields
id: TabIdUnique identifier for this tab
terminal: Arc<Mutex<TerminalManager>>The terminal session for this tab
title: StringTab title (from OSC sequences or fallback)
has_activity: boolWhether this tab has unread activity since last viewed
scroll_state: ScrollStateScroll state for this tab
mouse: MouseStateMouse state for this tab
bell: BellStateBell state for this tab
cache: RenderCacheRender cache for this tab
refresh_task: Option<JoinHandle<()>>Async task for refresh polling
working_directory: Option<String>Working directory when tab was created (for inheriting)
Implementations
Sourceimpl Tab
impl Tab
Sourcepub fn new(
id: TabId,
config: &Config,
_runtime: Arc<Runtime>,
working_directory: Option<String>,
) -> Result<Self>
pub fn new( id: TabId, config: &Config, _runtime: Arc<Runtime>, working_directory: Option<String>, ) -> Result<Self>
Create a new tab with a terminal session
Sourcepub fn is_bell_active(&self) -> bool
pub fn is_bell_active(&self) -> bool
Check if the visual bell is currently active (within flash duration)
Sourcepub fn update_title(&mut self)
pub fn update_title(&mut self)
Update tab title from terminal OSC sequences
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool
Check if the terminal in this tab is still running
Sourcepub fn start_refresh_task(
&mut self,
runtime: Arc<Runtime>,
window: Arc<Window>,
max_fps: u32,
)
pub fn start_refresh_task( &mut self, runtime: Arc<Runtime>, window: Arc<Window>, max_fps: u32, )
Start the refresh polling task for this tab
Sourcepub fn stop_refresh_task(&mut self)
pub fn stop_refresh_task(&mut self)
Stop the refresh polling task